/*
 * Example for MCP1664 click
 *
 * Date         Apr 2017
 * Author       Danilo Milovic
 *
 * Test configuration PIC :
 *  MCU           :        P18F45K22
 *  Dev. Board    :        EasyPIC v7
 *  SW            :        mikroC PRO for PIC v7.1.0
 *
 * Description :
 * Place MCP1664 click in mikroBus socket 2
 * This example shows basic control of light brightness with PWM,
 * duty cycle is controled with potentiometer P1, jumper J15 needs to be set on A1
 * CAUTION: Do not look directly at LED's.
 ******************************************************************************/

  #include <built_in.h>
  #include <stdint.h>
  /**************************************************************************
  * Module Variable Definitions
  **************************************************************************/



  uint16_t current_duty;
  uint16_t adc_rd;

  void MCU_Init()
  {
    TRISC = 0;                          // designate PORTC pins as output
    LATC  = 0;                          // set PORTC to 0
    PWM2_Init( 5000 );                  // Initialize PWM2 module at 5KHz
  }

  void main()
  {
    MCU_Init();
    current_duty  = 0;
    PWM2_Start();
    PWM2_Set_Duty(current_duty);

    while ( 1 )                         // Playing with Potentiometer P1 you can control current PWM duty cycle

    {
      adc_rd = ADC_Read(1) & 0x0000FFFF;         // Read 10 - bit ADC value and set newly acquired 8 - bit PWM duty
      current_duty = adc_rd / 4 ;
      PWM2_Set_Duty(current_duty );          // Set newly acquired duty
     }


  }
  